ElementDaiFormatSet

Struct ElementDaiFormatSet 

pub struct ElementDaiFormatSet {
    pub element_id: Option<u64>,
    pub format_sets: Option<Vec<DaiSupportedFormats>>,
    /* private fields */
}
This table represents the possible Dai formats that this transport can support.

Fields

element_id: Option<u64>

The ID of the element being described. This must match a DAI_INTERCONNECT entry in the list of elements contained in the device’s Info table. If describing the supported DAI formats for a Codec device, this value should be DEFAULT_DAI_INTERCONNECT_ELEMENT_ID (1).

Required.

format_sets: Option<Vec<DaiSupportedFormats>>

The dai_format_set entries that this element supports.

Required. Must contain at least one entry.