pub struct PacketStreamProxy { /* private fields */ }Implementations
Sourceimpl PacketStreamProxy
impl PacketStreamProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.audio.device/PacketStream.
Sourcepub fn take_event_stream(&self) -> PacketStreamEventStream
pub fn take_event_stream(&self) -> PacketStreamEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn set_buffers(
&self,
payload: PacketStreamSetBuffersRequest,
) -> QueryResponseFut<PacketStreamSetBuffersResult, DefaultFuchsiaResourceDialect>
pub fn set_buffers( &self, payload: PacketStreamSetBuffersRequest, ) -> QueryResponseFut<PacketStreamSetBuffersResult, DefaultFuchsiaResourceDialect>
Configures the shared memory buffers used to transfer audio data.
This method must be called before Start unless INLINE buffer type is supported
and the client intends to exclusively use inline data transfer.
Sourcepub fn start(
&self,
payload: &PacketStreamStartRequest,
) -> QueryResponseFut<PacketStreamStartResult, DefaultFuchsiaResourceDialect>
pub fn start( &self, payload: &PacketStreamStartRequest, ) -> QueryResponseFut<PacketStreamStartResult, DefaultFuchsiaResourceDialect>
Start the packet stream.
Sourcepub fn stop(
&self,
payload: &PacketStreamStopRequest,
) -> QueryResponseFut<PacketStreamStopResult, DefaultFuchsiaResourceDialect>
pub fn stop( &self, payload: &PacketStreamStopRequest, ) -> QueryResponseFut<PacketStreamStopResult, DefaultFuchsiaResourceDialect>
Stop the packet stream.