pub struct PacketStreamSynchronousProxy { /* private fields */ }Implementations
Sourceimpl PacketStreamSynchronousProxy
impl PacketStreamSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<PacketStreamEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<PacketStreamEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn set_buffers(
&self,
payload: PacketStreamSetBuffersRequest,
___deadline: MonotonicInstant,
) -> Result<PacketStreamSetBuffersResult, Error>
pub fn set_buffers( &self, payload: PacketStreamSetBuffersRequest, ___deadline: MonotonicInstant, ) -> Result<PacketStreamSetBuffersResult, Error>
Configures the shared memory buffers used to transfer audio data.
This method must be called before Start unless INLINE buffer type is supported
and the client intends to exclusively use inline data transfer.
Sourcepub fn start(
&self,
payload: &PacketStreamStartRequest,
___deadline: MonotonicInstant,
) -> Result<PacketStreamStartResult, Error>
pub fn start( &self, payload: &PacketStreamStartRequest, ___deadline: MonotonicInstant, ) -> Result<PacketStreamStartResult, Error>
Start the packet stream.
Sourcepub fn stop(
&self,
payload: &PacketStreamStopRequest,
___deadline: MonotonicInstant,
) -> Result<PacketStreamStopResult, Error>
pub fn stop( &self, payload: &PacketStreamStopRequest, ___deadline: MonotonicInstant, ) -> Result<PacketStreamStopResult, Error>
Stop the packet stream.